@@ -158,7 +158,6 @@ class LadybugExtensionScalarOpsMixin(ExtensionScalarOpsMixin):
 
 class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
 
-    # _dtype = LadybugDtype()
     _dtype = LadybugDType()
 
     def __init__(self, values, dtype=None, copy=False):
@@ -396,6 +395,11 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
 
         return view
 
+    def __arrow_array__(self, type=None):
+        # convert the underlying array values to a pyarrow Array
+        import pyarrow as pa
+        return pa.array(self.data, type=pa.float64())
+
 
     def __len__(self) -> int:
         """
@@ -774,4 +778,4 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
 
 
 LadybugArrayType._add_arithmetic_ops()
-LadybugArrayType._add_comparison_ops()
\ No newline at end of file
+LadybugArrayType._add_comparison_ops()
